package com.ruoyi.web.modules.architecture.mapper;

import java.util.List;
import com.ruoyi.web.modules.architecture.domain.BizBreedingStandard;

/**
 * 养殖标准 Mapper
 */
public interface BizBreedingStandardMapper
{
    BizBreedingStandard selectBizBreedingStandardById(Long id);

    List<BizBreedingStandard> selectBizBreedingStandardList(BizBreedingStandard query);

    int insertBizBreedingStandard(BizBreedingStandard row);

    int updateBizBreedingStandard(BizBreedingStandard row);

    int deleteBizBreedingStandardById(Long id);

    int deleteBizBreedingStandardByIds(Long[] ids);
}
